%function calculates absorption cross section for Yb3+ at given wavelength units: [m2]
function absorption=Yb_abs(lam)

% energy levels taken from IEEE JSTQE 1995 p2
C0=29979245800.; %speed of light [cm/s]
%absorbtion
Ea_e=10260.; %energy difference between levels a and e [1/cm], i.e. frequency/C0
Ea_f=11000.;
Ea_g=11630.;
Eb_e=10260.-600.;
Eb_f=11000.-600.;
Eb_g=11630.-600.;
%emission
Ec_e=10260.-1060.;
Ed_e=10260.-1490.;
Ec_f=11000.-1060.;
Ed_f=11000.-1490.;

% frequency=Ea_e*C0; wavelength[m]=0.01*C0/frequency => wavelength[m]=0.01/Ea_e
La_e=0.01/Ea_e;
La_f=0.01/Ea_f;
La_g=0.01/Ea_g;
Lb_e=0.01/Eb_e;
Lb_f=0.01/Eb_f;
Lb_g=0.01/Eb_g;
Lc_e=0.01/Ec_e;
Ld_e=0.01/Ed_e;
Lc_f=0.01/Ec_f;
Ld_f=0.01/Ed_f;

width_A=0.005e-6;
Lor_A=2.35*exp(-((lam-La_e)/width_A).^2);
width_B1=0.022e-6;
Lor_B1=.70*exp(-((lam-La_f)/width_B1).^2);
width_B2=0.02e-6;
Lor_B2=.05*exp(-((lam-La_g)/width_B2).^2);
width_C1=0.02e-6;
Lor_C1=.005*exp(-((lam-Lb_e)/width_C1).^2);
width_C2=0.04e-6;
Lor_C2=.15*exp(-((lam-Lb_f)/width_C2).^2);
width_C3=0.04e-6;
Lor_C3=.10*exp(-((lam-Lb_g)/width_C3).^2);

% levels added later to increase absorption cs for longer wavelengths
width_D2=0.04e-6;
Lor_D2=.0015*exp(-((lam-Lc_e)/width_D2).^2);
width_D3=0.04e-6;
Lor_D3=.00050*exp(-((lam-Ld_e)/width_D3).^2);
width_E2=0.04e-6;
Lor_E2=.0015*exp(-((lam-Lc_f)/width_E2).^2);
width_E3=0.04e-6;
Lor_E3=4*.0010*exp(-((lam-Ld_f)/width_E3).^2);

absorption=1.e-24*(Lor_A+Lor_B1+Lor_B2+Lor_C1+Lor_C2+Lor_C3+Lor_D2+Lor_D3+Lor_E2+Lor_E3);


