% Fourier Method propagation for a Gaussian shape optical beam
clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
I=sqrt(-1); % remember not to overwrite pi or I !
pi=3.141592653589793e+000;
 
 
lam=1.06; % wavelength [mi]
n=1.0; % refractive index of the medium
k=2*pi*n/lam;
 
wind_width=600;% numerical window width[mi]
NoSamp=2^12; % number of samples
dx=wind_width/NoSamp;
x_init=dx*(0:NoSamp-1); % x values
x=x_init-wind_width/2;
 
% calcuating the initial beam distribution
beam_width=30; % beam half width[mi]
teta=pi/24; %beam tilt angle
E=exp(-x.*x/(beam_width*beam_width)).*exp(-I*k*x*sin(teta));
Z(1,:)=abs(E).*abs(E);
X=x;
Y(1)=0;
 
dist_step=60.; %propagation distance [mi]
for m=1:50
kx=2*pi*(-NoSamp/2:NoSamp/2-1)/(NoSamp*dx); % calculating the values of kx
%calculating kz and changing the sign of the imaginary part to keep stable
kz=sqrt(k^2-kx.^2);
mask1=imag(kz)>0;
mask2=imag(kz)<=0;
kz=-mask1.*kz+mask2.*kz; 
%calculating the field at the next z position
fE=(fft(E));
fE=fftshift(fE);
fE1=fE.*exp(-I*dist_step*kz);
fE1=ifftshift(fE1);
E1=ifft(fE1); % field at position z = dist
E=E1;
Z(m+1,:)=abs(E).*abs(E);
Y(m+1)=m*dist_step;
end
 
contourf(X,Y,Z,'EdgeColor','none')
xlabel('x/micrometers','Fontsize',20)
ylabel('z/micrometers','Fontsize',20)
colormap cool
