% program calculates propagation constants for slab waveguide
clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
i=sqrt(-1); % remember not to overwrite pi or i !
pi=3.141592653589793e+000;

lam=1.55; %wavelength [micrometers]
nc=3.2874; % refractive index in cladding
nf=3.3704; % refractive index in core
ns=3.2874; % refractive index in substrate
g=2.; % waveguide thickness [micrometers]
m=0; % mode order

aE=(ns*ns-nc*nc)/(nf*nf-ns*ns); % parameter AE

nH(1)=nf*nf/(ns*ns);
nH(2)=nf*nf/(nc*nc);
%nH(1)=1; %TE
%nH(2)=1; %TE
% calculation parameters
k=2.0*pi/lam; % wavenumber
V=g*k*sqrt(nf^2-ns^2); % normalised frequency V

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of initial interval locating B for bisection method
b=(0.0199999:0.01:0.9999999);
% Dispersion equation
DE=m*pi+atan(nH(1)*sqrt(b./(1-b)))+...
atan(nH(2)*sqrt((b+aE)./(1-b)))-V*sqrt(1-b);

% precise initial location of B
length=size(b);
for j=length(2):-1:2  
   if DE(j)/DE(j-1)<0
      break
   end
end

if j==2
   disp('no zero found, change initial interval')
   disp('the results are incorrect')
end
  
btop=b(j);
bbot=b(j-1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bisection method for root finding starting from the initial interval 
DEtop=m*pi+atan(nH(1)*sqrt(btop/(1-btop)))+...
atan(nH(2)*sqrt((btop+aE)/(1-btop)))-V*sqrt(1-btop);
DEbot=m*pi+atan(nH(1)*sqrt(bbot/(1-bbot)))+...
atan(nH(2)*sqrt((bbot+aE)/(1-bbot)))-V*sqrt(1-bbot);
jmax=100;                           % maximum number of bisections
tolerance=0.00000000000001;                 % tolerance for finding B

for j=1:jmax
   bcen=(btop-bbot)/2+bbot;
   DEcen=m*pi+atan(nH(1)*sqrt(bcen/(1-bcen)))+...
   atan(nH(2)*sqrt((bcen+aE)/(1-bcen)))-V*sqrt(1-bcen);
   if DEtop/DEcen > 0
      btop=bcen;
      DEtop=DEcen;
      else
      bbot=bcen;
      DEbot=DEcen;
   end

   delta=btop-bbot;
   if delta < tolerance
      break
   end
end
%end of bisection method loop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% checks for tolerance
if j==jmax
   disp('maximum number of bisections exceeded before reaching tolerance')
else
   out=bcen;
end
% variable 'out' stores the relative propagation constant B

nin=abs(sqrt(out*(nf*nf-ns*ns)+ns*ns)); % calculation of effective index

[V out nin] %plotting results in one line