% program calculates normalised propagation constant for single step 
% optical fibres after A.Majewski 'Teoria ..' p.78 from H-D equation
format long e
% fiber definition
lambda=1.55;
radius=7.5;
na=1.46;
nc=1.47;
m=1;

% calculation parameters
k=2.0*pi/lambda;
V=radius*k*sqrt(nc^2-na^2);
B=(0.05:0.00001:0.999);

% Hondros-Debye equation
HD=hdf(m,nc,na,V,B);  % using external function hdf from home directory
zero=0.*B;
plot(B,1./HD,B,zero)% plotting inverse of HD shows clearly zeros

% precise initial location of B
length=size(B);
for j=length(2):-1:2  
   if HD(j)/HD(j-1)<0
      break
   end
end

if j==2
   disp('no zero found, change initial interval')
   disp('the results are incorrect')
end
  
btop=B(j);
bbot=B(j-1);
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bisection method for root finding starting from the initial interval 
DEtop=hdf(m,nc,na,V,btop);
DEbot=hdf(m,nc,na,V,bbot);
jmax=100;                           % maximum number of bisections
tolerance=0.0000000000001;                 % tolerance for finding B

for j=1:jmax
   bcen=(btop-bbot)/2+bbot;
   DEcen=hdf(m,nc,na,V,bcen);
   if DEtop/DEcen > 0
      btop=bcen;
      DEtop=DEcen;
      else
      bbot=bcen;
      DEbot=DEcen;
   end

   delta=btop-bbot;
   if delta < tolerance
      break
   end
end
%end of bisection method loop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% checks for tolerance
if j==jmax
   disp('maximum number of bisections exceeded before reaching tolerance')
else
   out=bcen;
end
% variable 'out' stores the relative propagation constant B

nin=abs(sqrt(out*(nc*nc-na*na)+na*na)); % calculation of effective index

[V out nin nin*k] % plotting results in one line