% program calculates propagation constants of MOF, cylindrical c.s.
% boundary conditions: zero field on external border and zero normal % derivative on symmetry plane
clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
I=sqrt(-1); % remember not to overwrite pi or i !
pi=3.141592653589793e+000;
 
wavelength=1.5;% wavelength [mi]
k0=2*pi/wavelength;
ref_in_ba=1.45; % background ref index
ref_in_ho=1.; % hole ref index
hole_rad=2; % hole radius [mi]
LAM=10.;% lattice constant [mi]
PC_first_lay=2; % first layer index
PC_no_lay=9; % number of PC hole layers (so if first=2, no_lay=4 then %the last PC hole layer is no 5)
 
boundary_condition=1;%boundary condition=0 - zero field on x axis; %boundary condition=1-zero derivative on x axis
shift=k0*1.4488;
 
% mesh params
window_radius=30; %window radius [mi]
dr=.2; % radial mesh size [mi]
window_angle=pi/6; %window angle [rad]
dt=window_angle/150; % angular mesh size [rad]-denominator gives the %number of nodes on the arc
no_nodes_r=round(window_radius/dr); % number of nodes in x direction %(the x waveguide dimension=dx*n_nodes_x*2)
no_nodes_t=round(window_angle/dt); % number of nodes in y direction %(the y waveguide dimension=dx*n_nodes_x*sqrt(3)*2) - in y direction %we do not count shifted nodes
no_nodes=no_nodes_r*no_nodes_t; %total number of nodes   
 
%creating a complex matrix with mesh node positions x-real part, y-%imaginary part
%as the origin of the coordinate system is placed in the centre of %symmetry and we consider only one quater the refernece point is %0+I*0
FD_radius=0.5*dr:dr:window_radius;%vector storing radial positions 
FD_angle=0.5*dt:dt:window_angle;%vector storing angular positions 
FD_mesh=ones(no_nodes,1);%matrix storing node positions row wise
 
for j1=1:no_nodes_r
    for j2=1:no_nodes_t
        FD_mesh((j1-1)*no_nodes_r+j2)=FD_radius(j1)*exp(I*FD_angle(j2));
    end
end
 
% calculating the lattice nodes positions (first part)
loop_count=1;
for j1=PC_first_lay:PC_no_lay+PC_first_lay-1
    for j2=1:j1
        PC_mesh(loop_count)=(j1-1)*LAM-(j2-1)*LAM/2+I*(j2-1)*LAM*sqrt(3)/2;
        loop_count=loop_count+1;
    end
end
 
 
% calculating the lattice nodes positions (rotated by 60 deg part)
for j1=PC_first_lay:PC_no_lay+PC_first_lay-1
    for j2=1:j1
        PC_mesh(loop_count)=((j1-1)*LAM-(j2-1)*LAM/2+I*(j2-1)*LAM*sqrt(3)/2)*exp(I*pi/3);
        loop_count=loop_count+1;
    end
end
PC_no_nodes=loop_count-1;
'finished calculating lattice positions'
 
% creating refractive index map in the mesh nodes
ref_in=ref_in_ba*ones(no_nodes,1);%matrix storing refractive indices %in nodes. It is initiated to background ref index
for j1=1:no_nodes
    test_con=1;
    j2=1;
    while test_con 
        if abs(FD_mesh(j1)-PC_mesh(j2)) < hole_rad            
            ref_in(j1)=ref_in_ho;
            test_con=0;
        end
        j2=j2+1; 
        if j2 > PC_no_nodes
            test_con=0;
        end
    end  
end
'set ref index values'
 
%setting up the matrix
FD_matrix1=zeros(no_nodes,5);%reserving space for complex matrix with %FD coefficients
 
%setting the initial pattern 
loop_count=1;
for j1=1:no_nodes_r
    for j2=1:no_nodes_t
        FD_matrix1(loop_count,2)=1/(dt*dt*FD_radius(j1)*FD_radius(j1));
        FD_matrix1(loop_count,3)=-2/(dr*dr)-2/(dt*dt*FD_radius(j1)*FD_radius(j1))+k0*k0*ref_in(loop_count)*ref_in(loop_count)-shift*shift;
        FD_matrix1(loop_count,4)=1/(dt*dt*FD_radius(j1)*FD_radius(j1));
        FD_matrix1(loop_count,1)=1/(dr*dr)-1/(2*dr*FD_radius(j1));
        FD_matrix1(loop_count,5)=1/(dr*dr)+1/(2*dr*FD_radius(j1));
        loop_count=loop_count+1;
    end
end
 
% adding periodic features %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
loop_count=1;
for j1=1:no_nodes_r
    FD_matrix1(loop_count,3)=FD_matrix1(loop_count,3)+FD_matrix1(loop_count,2);
    FD_matrix1(loop_count+no_nodes_t-1,3)=FD_matrix1(loop_count+no_nodes_t-1,3)+FD_matrix1(loop_count+no_nodes_t-1,4);
    loop_count=loop_count+no_nodes_t;
end
 
%including zero field option
if abs(boundary_condition)<1.d-16
    'boundary zero field'
    loop_count=1;
    for j1=1:no_nodes_r
        FD_matrix1(loop_count,3)=FD_matrix1(loop_count,3)-2*FD_matrix1(loop_count,2);%FD_matrix1(loop_count,1)=0 so omitted
        loop_count=loop_count+no_nodes_t;
    end
end
 
% setting zeros in off diagonals
loop_count=1;
for j1=1:no_nodes_r-1
    FD_matrix1(loop_count+no_nodes_t,2)=0;
    FD_matrix1(loop_count+no_nodes_t-1,4)=0;
    loop_count=loop_count+no_nodes_t;
end
 
 
%initial matrix created %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
 
%shifting columns for fitting spdiag format
FD_matrix1(:,1)=circshift(FD_matrix1(:,1),-no_nodes_t);
FD_matrix1(:,2)=circshift(FD_matrix1(:,2),-1);
FD_matrix1(:,4)=circshift(FD_matrix1(:,4),1);
FD_matrix1(:,5)=circshift(FD_matrix1(:,5),no_nodes_t);
% 
FD_matrix2=spdiags(FD_matrix1, [-no_nodes_t -1 0 1 no_nodes_t], no_nodes, no_nodes);
 
'started calculating eigenvalues'
%calculating eigenvalues and plotting
aug=ones(no_nodes,1); %augmented vector
augp=ones(no_nodes,1); %augmented vector after forward substitution
 
tol=.05e-1;
maxit=150;
droptol=0.0001;
[L,U]= luinc(FD_matrix2,droptol);
'finished ilu'
for i=1:8
    x0=aug;
    augp=aug;
    aug=bicgstab(FD_matrix2,aug,tol,maxit,L,U,x0);
    eigenval=(aug'*augp)/(aug'*aug);
    [i,eigenval,sqrt(eigenval+shift*shift)/k0]
end


a=sqrt(eigenval+shift*shift)/k0; %eigenvalues

[dr dt a]