% CN FDBPM propagation in two core slab waveguide

% ********************************************************
% calculation modes for 2 core slab waveguide using FDs; 
clear
format long e
pi=3.141592653589793e+000;
i=sqrt(-1);

lam=1.55; % wavelength in [micrometers]
k0=2*pi/lam; % wave number k0
nf=3.3704; % refractive index in core 1&2
nf12=3.2874; % refractive index between core 1&2
ns=3.2874; % refractive index in cladding
nc=3.2874; % refractive index in substrate

dist_c=4; % distance to edge of the window in cladding [micrometers]
dist_s=4; % distance to edge of the window in substrate [micrometers]
t1=2; % core 1 thickness in [micrometers]
t2=2; % core 2 thickness in [micrometers]
dist_t12=2; % core spacing in [micrometers]
No_t1=10; % number of mesh points in waveguide core 1
dx=t1/No_t1; % dx in [micrometers]
No_c=dist_c/dx; % number of mesh points in cladding
No_s=dist_s/dx; % number of mesh points in substrate
No_t2=t2/dx; % number of mesh points in waveguide core 2
No_t12=dist_t12/dx; % number of mesh points between core 1 & 2
N_tot=No_c+No_t1+No_t12+No_t2+No_s; % total number of mesh points

x=(1:N_tot)*dx; %vector with positions of FD nodes

c=1/(dx*dx); 
A=zeros(N_tot); % initialisation of matrix A
% setting off diagonals
for j=1:N_tot
    a1(j)=c;
    a3(j)=c;
end

% setting up vector storing the values of refractive index
n=ns*ones(N_tot,1); 
for j=1:No_c
    n(j)=nc;
end
for j=No_c+1:No_c+No_t1
    n(j)=nf;
end    
for j=No_c+No_t1+1:No_c+No_t1+No_t12
    n(j)=nf12;
end 
for j=No_c+No_t1+No_t12+1:No_c+No_t1+No_t12++No_t1
    n(j)=nf;
end

% setting main diagonal of the matrix
shift=nf*nf*k0*k0;
a2=((n.*n*k0*k0-2*c)-shift);

A=spdiags([a1' a2 a3'], -1:1, N_tot, N_tot); 

SIGMA='SM';
[X,D]=eigs(A,2,SIGMA); 

'propagation constants of supermodes'
beta=sqrt(diag(D)+shift) 
'effective refractive indices of supermodes'
neff=beta/k0 

%subplot(2,2,1)
%plot(x,nf*X(:,1)/ max(abs(X(:,1))),x,nf*X(:,2)/ max(abs(X(:,2))),x,n)

% ***********************************************************
% CN FDBPM

nref=nf; % reference refractive index
dz=0.01; % propagation step [micrometers]
% setting main diagonal of the matrix M
shift=nref*nref*k0*k0;
a2=((n.*n*k0*k0-2*c)-shift);

M=spdiags([a1' a2 a3'], -1:1, N_tot, N_tot); 
M=(-i/(2*nref*k0))*M;

M_prop1=sparse(diag(ones(N_tot,1)))+0.5*dz*M;
M_prop2=sparse(diag(ones(N_tot,1)))-0.5*dz*M;
N_steps=10000;
E_init=X(:,1)/ max(abs(X(:,1))); %initial field distribution
E=E_init;
for j=1:N_steps
   E=M_prop1*E;
   E=M_prop2\E;
   power(j)=sum(abs(E).^2);
   j
end

subplot(2,2,1)
plot(x,real(E_init),'Linewidth',2,'Color',[0. 0. 0.])
xlabel('x/micrometer','Fontsize',12)
ylabel('Re(A(x,z=0))','Fontsize',12)
axis([0 14 -1 0]) 

subplot(2,2,2)
plot(x,imag(E_init),'Linewidth',2,'Color',[0. 0. 0.])
xlabel('x/micrometer','Fontsize',12)
ylabel('Im(A(x,z=0))','Fontsize',12)
axis([0 14 -1 1])

subplot(2,2,3)
plot(x,real(E),'Linewidth',2,'Color',[0. 0. 0.])
xlabel('x/micrometer','Fontsize',12)
ylabel('Re(A(x,z=L))','Fontsize',12)
axis([0 14 -1 0])

subplot(2,2,4)
plot(x,imag(E),'Linewidth',2,'Color',[0. 0. 0.])
xlabel('x/micrometer','Fontsize',12)
ylabel('Im(A(x,z=L))','Fontsize',12)
axis([0 14 -1 1])





