% erbium doped fibre amplifier co-propagating pump
% using the full calculation of transverse photon flux distribution
 
clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
i=sqrt(-1); % remember not to overwrite pi or i !
pi=3.141592653589793e+000;

%*************************************************************
fiber_scalar_beta_s

scalar_fibre_plot1D

FF_s=f.*f;

fiber_scalar_beta_p

scalar_fibre_plot1D

FF_p=f.*f;

subplot(3,1,1)

r=r*1e-4; % converting microns to cm for radius
a=a*1e-4; % and fibre radius

plot(r,FF_s,'b',r,FF_p,'r')

xlabel('r/micrometers','Fontsize',12)
ylabel('Intensity/a.u.','Fontsize',12)
%*************************************************************

h=6.626e-34; %[Js]
v0=3e10; %[cm/s]
q=1.609e-19; %[C]
sig_p=2.7e-21; % pump absorption cross section [cm2]
sig_s=7e-21; % signal emission cross section [cm2]
N=0.7e19; % erbium ion concentration [1/cm3]
L=1500; % amplifier length [cm]
R=3.4e-4; % doping radius [cm]
if R > a 
    'doping radius larger than fibre core radius'
end
r_mask= r < R; % radius mask for integral calculation
dr=r(2)-r(1); % sampling step for integral calculation
A=pi*R*R;

gamma_s=sum(r_mask.*r.*FF_s)/(sum(r.*FF_s));
gamma_p=sum(r_mask.*r.*FF_p)/(sum(r.*FF_p));

lamp=0.98e-4; % pump wavelength[cm]
lams=1.53e-4; % signal wavelength[cm]
freqp=v0/lamp; %[1/s]
freqs=v0/lams; %[1/s]
tau21=9e-3; %[s]
Pp_ini=0.05; %pump power [W]
Ps_ini=1.e-6; %signal power [W]

% iteration loop
N_of_zsecs=1000% number of z sections
dL=L/N_of_zsecs; % z step
z_pos=dL*(1:1:N_of_zsecs);

Ps=Ps_ini*ones(1,N_of_zsecs); %initial signal wave relative intensity
Pp=Pp_ini*ones(1,N_of_zsecs); %initial pump wave relative intensity

for k=1:N_of_zsecs-1 
    Fi_s=Ps(k)*FF_s/((h*freqs)*2*pi*dr*sum(r.*FF_s));
    Fi_p=Pp(k)*FF_p/((h*freqp)*2*pi*dr*sum(r.*FF_p));
    mian=sig_p*Fi_p+2*sig_s*Fi_s+1/tau21;
    N2mN1=(sig_p*Fi_p-1/tau21).*r_mask*N./mian;    
    N3mN1=-(sig_s*Fi_s+1/tau21).*r_mask*N./mian;
    Gam_s=nc*sum(sig_s*N2mN1.*r.*FF_s)/(nin*sum(r.*FF_s));
    Gam_p=nc*sum(sig_p*N3mN1.*r.*FF_p)/(nin*sum(r.*FF_p));
    Ps(k+1)=Ps(k)+dL*Gam_s*Ps(k);
    Pp(k+1)=Pp(k)+dL*Gam_p*Pp(k);
end


subplot(3,1,2)
plot(z_pos,10*log10(Ps/(1e-3)))
xlabel('z/cm','FontSize',14)
ylabel('Signal Power [dBm]','FontSize',14)
subplot(3,1,3)
plot(z_pos,10*log10(Pp/(1e-3)))
xlabel('z/cm','FontSize',14)
ylabel('Pump Power [dBm]','FontSize',14)
[R Ps(N_of_zsecs)/(1e-3) 10*log10(Ps(N_of_zsecs)/Ps(1)) gamma_s gamma_p]
