% erbium doped fibre amplifier co-propagating pump
 
clear
format long e
pi=3.141592653589793e+000;

h=6.626e-34; %[Js]
v0=3e10; %[cm/s]
q=1.609e-19; %[C]
sig_p=2.7e-21; % pump absorption cross section [cm2]
sig_s=7e-21; % signal emission cross section [cm2]
N=0.7e19; % erbium ion concentration [1/cm3]
L=1500; % amplifier length [cm]
gamma_p=    9.349790276669653e-001; %confinement factor at pump wavelength
gamma_s=8.191686995681956e-001; %confinement factor at signal wavelength
R=3.4e-4; % doping radius [cm]
A=pi*R*R;

lamp=0.98e-4; % pump wavelength[cm]
lams=1.53e-4; % signal wavelength[cm]
freqp=v0/lamp; %[1/s]
freqs=v0/lams; %[1/s]
tau21=9e-3; %[s]
Pp_ini=0.05; %pump power [W]
Ps_ini=1.e-6; %signal power [W]

% iteration loop
N_of_zsecs=1000% number of z sections
dL=L/N_of_zsecs; % z step
z_pos=dL*(1:1:N_of_zsecs);

Ps=Ps_ini*ones(1,N_of_zsecs); %initial signal wave relative intensity
Pp=Pp_ini*ones(1,N_of_zsecs); %initial pump wave relative intensity

for k=1:N_of_zsecs-1 
    Ss=sig_s*Ps(k)*gamma_s/(A*h*freqs);
    Sp=sig_p*Pp(k)*gamma_p/(A*h*freqp);
    mian=Sp+2*Ss+1/tau21;
    Ps(k+1)=Ps(k)+dL*(Sp-1/tau21)*sig_s*Ps(k)*N*gamma_s/mian;
    Pp(k+1)=Pp(k)-dL*(Ss+1/tau21)*sig_p*Pp(k)*N*gamma_p/mian;
end


subplot(2,1,1)
plot(z_pos,10*log10(Ps/(1e-3)))
xlabel('z/cm','FontSize',14)
ylabel('Signal Power [dBm]','FontSize',14)
subplot(2,1,2)
plot(z_pos,10*log10(Pp/(1e-3)))
xlabel('z/cm','FontSize',14)
ylabel('Pump Power [dBm]','FontSize',14)
[R Ps(N_of_zsecs)/(1e-3) 10*log10(Ps(N_of_zsecs)/Ps(1)) gamma_s gamma_p]
