clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
I=sqrt(-1); % remember not to overwrite pi or i !
pi=3.141592653589793e+000;

% setting wavelength grid storing pump and signal wavelengths
global LAM_GRID
LAM_PUMP=0.915e-6; %pump wavelength [m]
LAM_SS=1.037e-6; %signal wavelength [m]
LAM_GRID=[LAM_PUMP;LAM_SS;LAM_PUMP;LAM_SS]; %pump and signal wavelengths in vertical vector for forw(1st) & back(2nd) waves

Fib_Len=1.; % fibre laser length [m]
Pp_forw=20.; %pump power forward [W] (input at left side, i.e. x=0)
%Pp_back=0000.; %pump power backward [W] (input at right side, i.e. x=Fib_Len)
ROC_p=0.035; %reflectivity for pump at output (on the right side: x=Fib_Len)
ROC_s=0.035; %reflectivity for signal at output (on the right side: x=Fib_Len)
RHR_p=0.0; %reflectivity for pump at dichroic HR coating (on the left side: x=0)
RHR_s=0.99; %reflectivity for signal at dichroic HR coating (on the left side: x=0)

%initial photon distribution
Y0=0.1*Pp_forw*ones(size(LAM_GRID)); %initial photon distribution for x=0 
Y0(1)=(1.-RHR_p)*Pp_forw; %setting initial value of forward pump
Y0(3)=0.0; %settinig initial value of backward pump (at x=0)

%calculation of the field distribution in the laser cavity %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
'start'
options = odeset('RelTol',1e-3,'AbsTol',1.e-6*ones(size(LAM_GRID))); % accuracy params for ode
for j1=1:4
    j1
	%forward integration
	[t,y]=ode45(@one_step1,[0 Fib_Len],Y0,options);
	%reflection at the right facet (x=Fib_len)
	Y0=y(size(y,1),:);
	%Y0(3)=ROC_p*Y0(1)+(1.0-ROC_p)*Pp_back;
    Y0(3)=ROC_p*Y0(1);
	Y0(4)=ROC_s*Y0(2);
	%backward integration
	[t,y]=ode45(@one_step1,[Fib_Len 0],Y0,options);
	%reflection at the left facet (x=0)
	Y0=y(size(y,1),:);
	Y0(1)=RHR_p*Y0(3)+(1.0-RHR_p)*Pp_forw;
	Y0(2)=RHR_s*Y0(4);
end

%plotting results %%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
subplot(2,1,1)
hold on
    plot(t,(y(:,1)),'Linewidth',2,'Color',[0.4 0.4 0.4])
    plot(t,(y(:,3)),'--','Linewidth',2,'Color',[0. 0. 0.])
    title('pump','FontSize',16)
    xlabel('z [m]','FontSize',16)
    ylabel('Power [W]','FontSize',16)
    legend('forward','backward','Location','NorthEastOutside')
    grid on
hold off
subplot(2,1,2)
hold on
    plot(t,(y(:,2)),'Linewidth',2,'Color',[0.4 0.4 0.4])
    plot(t,(y(:,4)),'--','Linewidth',2,'Color',[0. 0. 0.])
    title('signal','FontSize',16)
    xlabel('z [m]','FontSize',16)
    ylabel('Power [W]','FontSize',16) 
    legend('forward','backward','Location','NorthEastOutside')
    grid on
hold off


% 
% subplot(2,1,1)
% plot(LAM_GRID(2:No_of_lams/2),(y(1,2:No_of_lams/2)),'*')
% xlabel('wavelength [m]','FontSize',16)
% ylabel('Power [W]','FontSize',16)
% 
% subplot(2,1,2)
% plot(LAM_GRID(2:No_of_lams/2),(y(1,2:No_of_lams/2)),'*')
% xlabel('wavelength [m]','FontSize',16)
% ylabel('Power [W]','FontSize',16)