% program calculates propagation of an optical pulse in a fibre 
% using split step FFT method
clear  % clears variables
clear global  % clears global variables
format long e
% initial constants
i=sqrt(-1); % remember not to overwrite pi or i !
pi=3.141592653589793e+000;

% fibre parameters
B2=-1.00;  % |beta2| [ps^2/km]
B3=0.0; % |beta3| [ps^3/km]
G=2; % gamma [1/(W*km)] 
P0=0.5; % pulse peak power [W]

% iput data
dz=1.;  % z step [km]
NoSamp=2^10; % number of samples 

wind_width=50;% numerical window width[ps]
dt=wind_width/NoSamp;

t_init=dt*(0:NoSamp-1); % t values
t=t_init-wind_width/2;

beam_width=1.; % beam half width[ps]
E_init=sqrt(P0)./cosh(t/beam_width); % initial field

veka=(0:NoSamp/2);
vekb=((-NoSamp/2+1):1:-1);
vekab=[veka vekb]; % setting frequencies from 0:pi and -pi:~0
freq=vekab*2*pi/wind_width; % calculates the values of omega 

E=E_init;
E=fft(E);
% main propagation loop
N_steps=50;
for j=1:N_steps
   ffun=E.*(exp(i*B2*freq.^2*dz/4-i*B3*freq.^3*dz/12)); % dispersion half step
   E1=ifft(ffun);
   E1=E1.*exp(i*G*abs(E1).^2*dz);  % nonlinear step
   E=fft(E1).*(exp(i*B2*freq.^2*dz/4-i*B3*freq.^3*dz/12)); % dispersion half step
   power(j)=sum(abs(ffun).^2);
end


plot(t,abs(ifft(E)).^2,'Linewidth',2,'Color',[0.4 0.4 0.4])
hold on
plot(t,abs((E_init)).^2,'Linewidth',2,'Color',[0. 0. 0.])
xlabel('time/ps','Fontsize',20)
ylabel('Power/W','Fontsize',20)
legend('Output','Input')

(power(N_steps)/power(1))

