% calculating beta for signal wavelength
% 15.01.2013

lam=1.53; %wavelength [micrometers]
nf=1.45; % refractive index in core IMAGINARY PART MUST BE ZERO!
nc=1.44; % refractive index in cladding

a=3.45; % waveguide radius [micrometers]

% calculation parameters
k=2.0*pi/lam; % wavenumber
V=a*k*sqrt(nf^2-nc^2); % normalised frequency V
mode_order=0; % LP mode order

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% Calculation of initial interval locating B for bisection method
b=(0.00199999:0.001:0.9999999);
% Dispersion equation
u=sqrt(1.0-b)*V;
w=sqrt(b)*V;
DE=u.*besselj(mode_order+1,u)./besselj(mode_order,u)-w.*besselk(mode_order+1,w)./besselk(mode_order,w);

% precise location of B
length=size(b);
for j=length(2):-1:2  % size produces a 2 el. vector with first element being vert dim and second long dim hence length(2) not length
   if DE(j)/DE(j-1)<0
      break
   end
end


btop=b(j);
bbot=b(j-1);
jbrowse=j-1;
utop=sqrt(1.0-btop)*V;
wtop=sqrt(btop)*V;
ubot=sqrt(1.0-bbot)*V;
wbot=sqrt(bbot)*V;

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% bisection method for root finding starting from the initial interval calculated above
DEtop=utop*besselj(mode_order+1,utop)/besselj(mode_order,utop)-wtop*besselk(mode_order+1,wtop)/besselk(mode_order,wtop);
DEbot=ubot*besselj(mode_order+1,ubot)/besselj(mode_order,ubot)-wbot*besselk(mode_order+1,wbot)/besselk(mode_order,wbot);
jmax=100;                           % maximum number of bisections
tolerance=0.000000000001;                 % tolerance for finding B

for j=1:jmax
   bcen=(btop-bbot)/2+bbot;
   ucen=sqrt(1.0-bcen)*V;
   wcen=sqrt(bcen)*V;
   DEcen=ucen*besselj(mode_order+1,ucen)/besselj(mode_order,ucen)-wcen*besselk(mode_order+1,wcen)/besselk(mode_order,wcen);
   
   if abs(DEcen) < 1.d-15 %added to avoid division by nearly zero
       break
   end
   
   if DEtop/DEcen > 0
      btop=bcen;
      DEtop=DEcen;
      else
      bbot=bcen;
      DEbot=DEcen;
   end

   delta=btop-bbot;
   if delta < tolerance
      break
   end
end

%end of bisection method loop
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
% checks for tolerance
if j==jmax
   disp('maximum number of bisections exceeded before reaching tolerance')
end

if jbrowse==1
%   disp('no zero found')
   out=0;
else
   out=bcen;
end
% variable 'out' stores the relative propagation constant B

nin=abs(sqrt(out*(nf*nf-nc*nc)+nc*nc)); % calculation of effective index
'V B neff beta'
[V out nin nin*k] % plotting results in one line

