function dydt = one_step1(t,y)
global LAM_GRID

pi=3.141592653589793e+000;
h=6.626e-34; %[Js]
v0=3e8; %[m/s]
Gamma_fibP=0.01; %confinement factor for pump (from JLT'03 p.2262)
Gamma_fibS=0.7; %confinement factor for signal
A_dopRE=3e-10; %rare earth doping cross section [m2]
tau_Yb=840.e-6; % life time for Yb [s]
N_Yb=6e25; %Yb dopant concentration [1/m3]
alfa_fib=1.e-1; %fiber loss [1/m]

Gamma_fib=Gamma_fibS*ones(size(LAM_GRID));
Gamma_fib(1)=Gamma_fib(1)*Gamma_fibP/Gamma_fibS;
Gamma_fib(3)=Gamma_fib(3)*Gamma_fibP/Gamma_fibS;
%calculation of C coefficient = gamma*lam/(h*c*A_dopRE)
C_Yb=Gamma_fib.*LAM_GRID/(h*v0*A_dopRE);

%calculation of level populations: N2 and N1
N2_Yb=N_Yb*sum(C_Yb.*Yb_abs(LAM_GRID).*y)/(1/tau_Yb+sum(C_Yb.*(Yb_abs(LAM_GRID)+Yb_ems(LAM_GRID)).*y));
N1_Yb=N_Yb-N2_Yb;

%calculation of RHS' of coupled ODEs
dydt=Gamma_fib.*(Yb_abs(LAM_GRID)*N1_Yb-Yb_ems(LAM_GRID)*N2_Yb).*y;
dydt(1:2)=-dydt(1:2); %introducing - sign in the equations for forward propagating waves
dydt(2)=dydt(2)-alfa_fib*y(2); %adding fiber loss term to forw signal wave
dydt(4)=dydt(4)+alfa_fib*y(4); %adding fiber loss term to back signal wave